import React, { useEffect } from 'react';
import { Modal, Form, Input, Select } from 'antd';
import '../../tencentAdPutIn/index.less'
import { useAjax } from '@/Hook/useAjax';
import { addCorpRelationListApi, getCorpListAllApi } from '@/services/adqV3/global';

interface Props {
    adAccountId: number
    visible?: boolean
    onChange?: () => void
    onClose?: () => void
}

/**
 * 新增企微与投放端关系
 * @param param0 
 * @returns 
 */
const AddWechatTieUp: React.FC<Props> = ({ adAccountId, visible, onChange, onClose }) => {

    /*******************************************/
    const [form] = Form.useForm();

    const addCorpRelationList = useAjax((params) => addCorpRelationListApi(params))
    const getCorpListAll = useAjax(() => getCorpListAllApi())
    /*******************************************/

    useEffect(() => {
        getCorpListAll.run()
    }, [])

    const handleOk = () => {
        form.validateFields().then(values => {
            const { corp, ...params } = values
            const [corpName, corpId] = corp.split('&&')
            addCorpRelationList.run({ adAccountId, corpName, corpId, ...params }).then((res) => {
                if (res)
                    onChange?.()
            })
        })
    };

    return <Modal
        title={<strong>新增企微与投放端关系</strong>}
        open={visible}
        onOk={handleOk}
        onCancel={onClose}
        className='modalResetCss'
        confirmLoading={addCorpRelationList.loading}
    >
        <Form
            form={form}
            name='basicWechatTieUp'
            autoComplete="off"
            colon={false}
            labelCol={{ span: 5 }}
            labelAlign="left"
        >
            <Form.Item label={<strong>企微端企业</strong>} name="corp" rules={[{ required: true, message: '请输入企微端企业!' }]}>
                <Select
                    showSearch
                    placeholder="请选择企微端企业"
                    filterOption={(input, option) =>
                        ((option?.label ?? '') as any).toLowerCase().includes(input.toLowerCase())
                    }
                    allowClear
                    options={getCorpListAll?.data?.map((item: { corpName: string; corpId: string; }) => ({ label: item.corpName, value: item.corpName + '&&' + item.corpId }))}
                />
            </Form.Item>
            <Form.Item label={<strong>投放端企业ID</strong>} name="tencentCorpId" rules={[{ required: true, message: '请输入投放端企业ID!' }]}>
                <Input placeholder='请输入投放端企业ID' />
            </Form.Item>
        </Form>
    </Modal>;
};

export default React.memo(AddWechatTieUp);